#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

export CFLAGS='-flto=auto -Os -pipe -march=armv8-a+crc -mtune=cortex-a72   '
export CXXFLAGS='-flto=auto -Os -pipe -fno-exceptions -fno-rtti -march=armv8-a+crc -mtune=cortex-a72  '
export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:/usr/lib/pkgconfig
echo $CFLAGS && echo $CXXFLAGS

P=libmd
V=1.1.0
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc squashfs-tools wget "
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

# list may be larger than loaded
cd /usr/local/lib
rm -rf *.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/plugin/*.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/*.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/plugin/libcc1plugin.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/plugin/libcp1plugin.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/liblto_plugin.la
rm -rf gprofng/*.la 
rm -rf python3.8/site-packages/*.la
rm -rf pkcs11/*.la
rm -rf cairo/*.la
rm -rf gtk-2.0/modules/*.la
rm -rf gtk-2.0/2.10.0/printbackends/*.la
rm -rf gtk-2.0/2.10.0/immodules/*.la
rm -rf gtk-2.0/2.10.0/engines/*.la
rm -rf imlib2/loaders/*.la
rm -rf imlib2/filters/*.la
rm -rf gdk-pixbuf-2.0/2.10.0/loaders/*.la
rm -rf pulseaudio/libpulsedsp.la
rm -rf pulseaudio/libpulsecore-13.0.la
rm -rf pulseaudio/libpulsecommon-13.0.la
rm -rf libv4l/v4l2convert.la
rm -rf libv4l/v4l1compat.la
rm -rf libv4l/plugins/libv4l-mplane.la
rm -rf vala-0.46/libvalaccodegen.la
cd /tmp
rm -rf /usr/lib/*.la
find / -name *.la

su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://archive.hadrons.org/software/$P/$SRC.tar.xz"  $USER
tar xvf $SRC*xz
cd $SRC
./configure --prefix=/usr/local --sysconfdir=/etc
make -j4 # 5 secs
make install-strip DESTDIR=/tmp/$P 
cd /tmp

# dev
#######
mkdir -p $P-dev/usr/local/lib
mv $P/usr/local/include $P-dev/usr/local/
mv $P/usr/local/lib/pkgconfig $P-dev/usr/local/lib
rm -rf $P/usr/local/lib/*.la
mv $P/usr/local/lib/*.a $P-dev/usr/local/lib

# main
#######
rm -rf $P/usr/local/share/man
mkdir -p $P/usr/local/share/doc/$P
cp $SRC/COPYING  $P/usr/local/share/doc/$P/	

# TCZ them
###########
LIST2="$P $P-dev "
for Z in $LIST2
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          libmd-dev.tcz
Description:    dev files
Version:        1.1.0
Author:         libmd Team 
Original-site:  https://www.hadrons.org/software/libmd/
Copying-policy: accompanied - many 
Size:           192K
Extension_by:   aus9
Tags:           png
Comments:       dev files

Change-log:     2023/09/22 v 1.1.0
Current:        2023/09/22           ' > $P-dev.tcz.info
echo 'libmd.tcz' > $P-dev.tcz.dep

echo 'Title:          libmd.tcz
Description:    Message Digest functions from BSD syste
Version:        1.1.0
Author:         libmd Team
Original-site:  https://www.hadrons.org/software/libmd/
Copying-policy: accompanied - many
Size:           28K
Extension_by:   aus9
Tags:           md5 sha256 
Comments:       Mainly md5 for TC

Change-log:     2023/09/22 v 1.1.0
Current:        2023/09/22               ' > $P.tcz.info

readelf -d $P/usr/local/lib/*.so | grep 'NEEDED' # TCBs

no dep

